#!/usr/bin/python3

import datetime

from .misc import Object

class Nopaste(Object):
	def create(self, subject, content, mimetype="text", expires=None, account=None, address=None):
		self._cleanup_database()

		uid = None
		if account:
			uid = account.uid

		if expires:
			expires = datetime.datetime.utcnow() + datetime.timedelta(seconds=expires)

		# http://blog.00null.net/easily-generating-random-strings-in-postgresql/
		res = self.db.get("INSERT INTO nopaste(uuid, subject, content, time_expires, address, \
			uid, mimetype, size) VALUES(random_slug(), %s, %s, %s, %s, %s, %s, %s) RETURNING uuid",
			subject, content, expires or None, address, uid, mimetype, len(content))

		if res:
			return res.uuid

	def get(self, uuid):
		res = self.db.get("SELECT uuid, subject, time_created, time_expires, address, uid, \
			mimetype, views, size FROM nopaste WHERE uuid = %s AND (CASE WHEN time_expires \
			IS NULL THEN TRUE ELSE NOW() < time_expires END)", uuid)

		if res:
			# Get the account that uploaded this if available
			res.account = None
			if res.uid:
				res.account = self.backend.accounts.get_by_uid(res.uid)

			# Touch the entry so it won't be deleted when it is still used
			self._update_lastseen(uuid)

		return res

	def get_content(self, uuid):
		res = self.db.get("SELECT content FROM nopaste \
			WHERE uuid = %s", uuid)

		if res:
			return bytes(res.content)

	def _update_lastseen(self, uuid):
		self.db.execute("UPDATE nopaste SET time_lastseen = NOW(), views = views + 1 \
			WHERE uuid = %s", uuid)

	def _cleanup_database(self):
		# Delete old pastes when they are expired or when they have not been
		# accessed in a long time.
		self.db.execute("DELETE FROM nopaste WHERE (CASE \
			WHEN time_expires IS NULL \
				THEN time_lastseen + INTERVAL '6 months' <= NOW() \
			ELSE NOW() >= time_expires END)")
