#!/usr/bin/python3

from . import base

class LangCompatHandler(base.BaseHandler):
	"""
		Redirect links in the old format to current site:

		E.g. /en/index -> /index
	"""
	def get(self, lang, page):
		self.redirect("/%s" % page)


class IndexHandler(base.BaseHandler):
	"""
		This handler displays the welcome page.
	"""
	def get(self):
		# Get the latest release.
		latest_release = self.releases.get_latest()

		# Cache page for 5 minutes
		self.set_expires(300)

		return self.render("index.html", latest_release=latest_release)


class NewsHandler(base.BaseHandler):
	def get(self, post):
		self.redirect("https://blog.ipfire.org/post/%s" % post, permanent=True)


class PlanetPostHandler(base.BaseHandler):
	def get(self, post):
		self.redirect("https://blog.ipfire.org/post/%s" % post, permanent=True)


class PlanetUserHandler(base.BaseHandler):
	def get(self, user):
		self.redirect("https://blog.ipfire.org/authors/%s" % user, permanent=True)


class StaticHandler(base.BaseHandler):
	def initialize(self, template):
		self._template = template

	def get(self):
		# Cache page for 60 minutes
		self.set_expires(3600)

		self.render("static/%s" % self._template)
